DNE3d(DNE_File, setRange = c(0, 0), edgeMask = TRUE, outlierMask = TRUE,
logColors = TRUE, showEdgePts = FALSE, fieldofview = 0, legend = TRUE)DNE
functionpar3d changing the field of
view in degrees of the resulting rglDNE function. Hottest colors represent highest normal energy
values.Dirichlet normal energies for the faces of a mesh surface tend to be
positively skewed, with a small proportion of the faces contributing
much of the total energy for the surface. When logColors is enabled the
function colorizes based on the log transformed Dirichlet normal
energies, allowing for finer resolution between faces near the mode of
the energy per face distribution. Disabling logColors will display the
untransformed Dirichlet normal energies.
The legend will update to reflect the other arguments chosen by the user. Colors currently display in the legend in bins, however the colors used in the displayed mesh surface are on a continuum. Ideally, the legend should reflect a continuous stretch of color from the lowest calculated Dirichlet normal energy to the highest. Future versions will adjust the legend to this more intuitive display.
By default, the function sets the lowest Dirichlet normal energy
calculated among all faces to a cool color and the highest normal energy
calculated among all faces to red, and then colors the remaining faces
on a continuous color spectrum between these two end points using
either absolute or log transformed Dirichlet normal energy values
(depending on the status of logColors). Since the scale is relative to the
energies of the input surface, visual comparisons cannot directly be
made between multiple plots of different surfaces. The code{setRange}
argument allows users to define the minimum and maximum of the
plotting color scheme and use it in multiple plots. This enables the
direct comparison of different surfaces to one another with red equal to
the user-defined maximum and a cool color equal to the user-defined
minimum. The user should choose reasonable bounds for the
maximum and minimum that are near the maximum and minimum
Dirichlet normal energies calculated for their surfaces. setRange will
not accept negative values.
fieldofview is set to a default of 0, which is an isometric projection.
Increasing it alters the degree of parallax in the perspective view, up to
a maximum of 179 degrees.