powered by
DNE_Legend(start, end, colors, DNELabels, scaled = F, edgeMask = F, outlierMask = F, logColors = F)
The legend will reflect the elements used in the plot. This is an internal function. Users will have little need or call to interact with it.