RFI(plyFile)read.ply or the read.AVIZO.ply function, with calculated normals.Relief index is calculated by the ratio of three-dimensional surface area to two
dimensional area on meshes that represent specimen surfaces and have already
been pre-smoothed in a 3D data editing program. Alignment of the point cloud
will have a large effect on patch orientation and must be done in a 3D data editing
program or auto3dgm prior to creating and reading in the ply file. The mesh
must be oriented such that the occlusal plane is parallel to the X- and Y-axes and
perpendicular to the Z-axis.