RFI3d(RFI_Output, displace = "Up", SurfaceColor = "gray",
FootColor = "red", fieldofview = 0, Transparency = 1, legend = F)RFI
functionpar3d changing the
field of view in degrees of the resulting rgl windowRFI function must be performed first.Transparency can be adjusted in a range from fully opaque (1) to fully
transparent (0) in order to help visualize the footprint. The vertical placement of
the footprint along the Z axis can be altered with displace depending on how the
user wishes to view the surface, or on the original mesh orientation.
fieldofview is set to a default of 0, which is an isometric projection. Increasing it
alters the degree of parallax in the perspective view, up to a maximum of 179
degrees.